/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                TERCER GRADO DE PREESCOLAR (Excale 00)
/*
/*                          **** CONTEXTO ****
/*                 ****** Respuestas de tutores (te)  ********
/*
/*                     Ciclo escolar evaluado: 2010 - 2011
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE CONTEXTO
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte el archivo Excale00_2011_Pad_Cuest.txt el cual est en
/*  formato ASCII a una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale00_2011_Pad_Cuest.txt
/*         as como el archivo Excale00_2011_Pad_Cuest.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale00_2011_Pad_Cuest.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale00_2011_Pad_Cuest.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 27 DE AGOSTO DE 2013
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale00_2011_Pad_Cuest.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbano Pblico"
                       2         ="Rural Pblico"
                       3         ="Educacin Indgena"
                       4         ="Cursos Comunitarios"
                       5         ="Privados";
     VALUE $modF       "UP"      ="Urbano Pblico"
                       "RP"      ="Rural Pblico"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privados"
                       "PUB"     ="Escuelas pblicas sin clasificar en Urbanas o Rurales. Slo se utilizan para estimacin de parmetros a nivel Nacional";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadcF      1         ="Cuatro aos o menos"
                       2         ="Cinco aos"
                       3         ="Seis aos"
                       4         ="Siete aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE i_padreF
                       0         ="No se present el padre o tutor a contestar el cuestionario"
                       1         ="El padre de familia o tutor contest el cuestionario";
     VALUE parentF
                       2         ="Si"
                       1         ="No, pero vivo con l"
                       0         ="No y tampoco vivo con l"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T1F
                        9         ="Respuesta omitida o invlida";
     VALUE T2F
                       1         ="Si"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T3F
                       99        ="Respuesta omitida o invlida";
     VALUE T4F
                       99        ="Respuesta omitida o invlida";
     VALUE T5F
                       1         ="Primera"
                       2         ="Segunda"
                       3         ="Tercera"
                       4         ="Cuarta"
                       5         ="Quinta"
                       6         ="Sexta"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T6F
                       1         ="Primera"
                       2         ="Segunda"
                       3         ="Tercera"
                       4         ="Cuarta"
                       5         ="Quinta"
                       6         ="Sexta"
                       7         ="Septima"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T7F
                       0         ="No se relacionan, son cosas diferentes"
                       1         ="Los conocimientos escolares se refuerzan y aplican en casa"
                       2         ="Hay cosas que se ensean en ambos sitios"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T8F
                       0         ="Siempre quiere ir"
                       1         ="Le prometo algn premio"
                       2         ="Lo amenazo o lo castigo"
                       3         ="Le explico por qu es bueno que vaya"
                       4         ="Lo llevo a la fuerza"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T9F
                       0         ="As est bien"
                       1         ="Debera ser ms corto"
                       2         ="Debera ser igual al de la primaria"
                       3         ="Debera ser ms parecido al horario de trabajo de los padres"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T10F
                       0         ="Son muy pocas, hacen falta ms opciones"
                       1         ="Son suficientes"
                       2         ="Son demasiadas, es difcil participar en todas"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T11F
                       1         ="S particip"
                       0         ="No particip"
                       2         ="La escuela no las organiza"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T12F
                       1         ="Me gustara / ya he participado"
                       0         ="No me gustara"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T13F
                       1         ="Si"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T14F
                       0         ="0 das"
                       1         ="1 da"
                       2         ="2 das"
                       3         ="3 das"
                       4         ="4 das"
                       5         ="5 das"
                       6         ="6 das"
                       7         ="7 das"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T15F
                       1         ="Mam o pap del nio"
                       2         ="Algn familiar (abuelos, hermanos)"
                       3         ="Otra persona (vecinos, amigos)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T16F
                       0         ="Yo no lo llevo ni lo recojo"
                       1         ="No"
                       2         ="Solamente cuando tengo alguna actividad especial"
                       3         ="Si"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T17F
                       0         ="No estoy de acuerdo en que sea obligatorio"
                       1         ="Slo un ao debera ser obligatorio"
                       2         ="Solamente dos aos deberan ser obligatorios"
                       3         ="Est bien que los tres aos sean obligatorios"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T18_19F
                       1         ="Una lengua indgena (nhuatl, maya, purpecha, mixteco, otom u otra)"
                       0         ="Espaol"
                       2         ="Un idioma extranjero (francs, ingls, alemn u otro)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T20F
                       2         ="Cemento con recubrimiento (loseta, alfombra, parquet, duela, etctera)"
                       1         ="Cemento sin recubrimiento"
                       0         ="Tierra, tablones sobre tierra"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T21F
                       0         ="Ninguno"
                       1         ="1"
                       2         ="2"
                       3         ="3  ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T22_23F
                       0         ="No fue a la escuela"
                       1         ="Primaria incompleta"
                       2         ="Primaria completa"
                       3         ="Secundaria incompleta"
                       4         ="Secundaria completa"
                       5         ="Bachillerato o preparatoria"
                       6         ="Licenciatura (carrera universitaria)"
                       7         ="Posgrado (maestra o doctorado)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T24F
                       0         ="Ninguno"
                       1         ="1"
                       2         ="2"
                       3         ="3  ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T25F
                       0         ="Primaria"
                       1         ="Secundaria"
                       2         ="Bachillerato o preparatoria"
                       3         ="Licenciatura"
                       4         ="Posgrado (maestra o doctorado)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE T26F
                       999       ="Respuesta omitida";
     VALUE T27F
                       999       ="Respuesta omitida o invlida";
     VALUE T28F
                       1         ="Si"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";

RUN;



DATA INEE.Excale00_2011_Pad_Cuest;
   LENGTH
       NACIONAL           3
       ESCUELA            4
       ID_ENT             3
       NOM_ENT            $19
       ID_MOD             3
       MOD                $4
       ESTRATO            $6
       ALUMNO             6
       ID_INSTR           $15
       SEXO               3
       FECHA_NAC          $10
       EDAD               8
       EDADC              3
       EDADN              3
       EDAD_AC            3
       W_ALU              8
       I_PADRES           3
       PARENT             3
       TE001              3
       TE002_1            3
       TE002_2            3
       TE002_3            3
       TE002_4            3
       TE002_5            3
       TE003_1            3
       TE003_2            3
       TE003_3            3
       TE003_4            3
       TE003_5            3
       TE003_6            3
       TE003_7            3
       TE003_8            3
       TE003_9            3
       TE004_01           3
       TE004_02           3
       TE004_03           3
       TE004_04           3
       TE004_05           3
       TE004_06           3
       TE004_07           3
       TE004_08           3
       TE004_09           3
       TE004_10           3
       TE004_11           3
       TE004_12           3
       TE004_13           3
       TE005_1            3
       TE005_2            3
       TE005_3            3
       TE005_4            3
       TE005_5            3
       TE005_6            3
       TE006_1            3
       TE006_2            3
       TE006_3            3
       TE006_4            3
       TE006_5            3
       TE006_6            3
       TE006_7            3
       TE007              3
       TE008              3
       TE009              3
       TE010              3
       TE011_01           3
       TE011_02           3
       TE011_03           3
       TE011_04           3
       TE011_05           3
       TE011_06           3
       TE011_07           3
       TE011_08           3
       TE011_09           3
       TE011_10           3
       TE011_11           3
       TE012_1            3
       TE012_2            3
       TE012_3            3
       TE012_4            3
       TE012_5            3
       TE012_6            3
       TE013_011          3
       TE013_012          3
       TE013_021          3
       TE013_022          3
       TE013_031          3
       TE013_032          3
       TE013_041          3
       TE013_042          3
       TE013_051          3
       TE013_052          3
       TE013_061          3
       TE013_062          3
       TE013_071          3
       TE013_072          3
       TE013_081          3
       TE013_082          3
       TE013_091          3
       TE013_092          3
       TE013_101          3
       TE013_102          3
       TE013_111          3
       TE013_112          3
       TE014_1            3
       TE014_2            3
       TE014_3            3
       TE014_4            3
       TE014_5            3
       TE014_6            3
       TE014_7            3
       TE014_8            3
       TE015              3
       TE016              3
       TE017              3
       TE018              3
       TE019              3
       TE020              3
       TE021              3
       TE022              3
       TE023              3
       TE024              3
       TE025              3
       TE026              3
       TE027              3
       TE028_1            3
       TE028_2            3
       TE028_3            3
       TE028_4            3
       TE028_5            3
       TE028_6            3
       TE028_7            3
       TE028_8            3
       WVARSTRR           3
       W_FSTR1            8
       W_FSTR2            8
       W_FSTR3            8
       W_FSTR4            8
       W_FSTR5            8
       W_FSTR6            8
       W_FSTR7            8
       W_FSTR8            8
       W_FSTR9            8
       W_FSTR10           8
       W_FSTR11           8
       W_FSTR12           8
       W_FSTR13           8
       W_FSTR14           8
       W_FSTR15           8
       W_FSTR16           8
       W_FSTR17           8
       W_FSTR18           8
       W_FSTR19           8
       W_FSTR20           8
       W_FSTR21           8
       W_FSTR22           8
       W_FSTR23           8
       W_FSTR24           8
       W_FSTR25           8
       W_FSTR26           8
       W_FSTR27           8
       W_FSTR28           8
       W_FSTR29           8
       W_FSTR30           8
       W_FSTR31           8
       W_FSTR32           8
       W_FSTR33           8
       W_FSTR34           8
       W_FSTR35           8
       W_FSTR36           8
       W_FSTR37           8
       W_FSTR38           8
       W_FSTR39           8
       W_FSTR40           8
       W_FSTR41           8
       W_FSTR42           8
       W_FSTR43           8
       W_FSTR44           8
       W_FSTR45           8
       W_FSTR46           8
       W_FSTR47           8
       W_FSTR48           8
       W_FSTR49           8
       W_FSTR50           8
       W_FSTR51           8
       W_FSTR52           8
       W_FSTR53           8
       W_FSTR54           8
       W_FSTR55           8
       W_FSTR56           8
       W_FSTR57           8
       W_FSTR58           8
       W_FSTR59           8
       W_FSTR60           8
       W_FSTR61           8
       W_FSTR62           8
       W_FSTR63           8
       W_FSTR64           8
       W_FSTR65           8
       W_FSTR66           8
       W_FSTR67           8
       W_FSTR68           8
       W_FSTR69           8
       W_FSTR70           8
       W_FSTR71           8
       W_FSTR72           8
       W_FSTR73           8
       W_FSTR74           8
       W_FSTR75           8
       W_FSTR76           8
       W_FSTR77           8
       W_FSTR78           8
       W_FSTR79           8
       W_FSTR80           8
   ;

INFILE alum MISSOVER LINESIZE = 1115;
   INPUT
       NACIONAL            1 - 1
       ESCUELA             2 - 5
       ID_ENT              6 - 7
       NOM_ENT             8 - 26
       ID_MOD             27 - 27
       MOD                28 - 31
       ESTRATO            32 - 37
       ALUMNO             38 - 42
       ID_INSTR           43 - 54
       SEXO               55 - 55
       FECHA_NAC          56 - 65
       EDAD               66 - 76
       EDADC              77 - 77
       EDADN              78 - 78
       EDAD_AC            79 - 80
       W_ALU              81 - 91
       I_PADRES           92 - 92
       PARENT             93 - 93
       TE001              94 - 95
       TE002_1            96 - 96
       TE002_2            97 - 97
       TE002_3            98 - 98
       TE002_4            99 - 99
       TE002_5           100 - 100
       TE003_1           101 - 102
       TE003_2           103 - 104
       TE003_3           105 - 106
       TE003_4           107 - 108
       TE003_5           109 - 110
       TE003_6           111 - 112
       TE003_7           113 - 114
       TE003_8           115 - 116
       TE003_9           117 - 118
       TE004_01          119 - 120
       TE004_02          121 - 122
       TE004_03          123 - 124
       TE004_04          125 - 126
       TE004_05          127 - 128
       TE004_06          129 - 130
       TE004_07          131 - 132
       TE004_08          133 - 134
       TE004_09          135 - 136
       TE004_10          137 - 138
       TE004_11          139 - 140
       TE004_12          141 - 142
       TE004_13          143 - 144
       TE005_1           145 - 145
       TE005_2           146 - 146
       TE005_3           147 - 147
       TE005_4           148 - 148
       TE005_5           149 - 149
       TE005_6           150 - 150
       TE006_1           151 - 151
       TE006_2           152 - 152
       TE006_3           153 - 153
       TE006_4           154 - 154
       TE006_5           155 - 155
       TE006_6           156 - 156
       TE006_7           157 - 157
       TE007             158 - 158
       TE008             159 - 159
       TE009             160 - 160
       TE010             161 - 161
       TE011_01          162 - 162
       TE011_02          163 - 163
       TE011_03          164 - 164
       TE011_04          165 - 165
       TE011_05          166 - 166
       TE011_06          167 - 167
       TE011_07          168 - 168
       TE011_08          169 - 169
       TE011_09          170 - 170
       TE011_10          171 - 171
       TE011_11          172 - 172
       TE012_1           173 - 173
       TE012_2           174 - 174
       TE012_3           175 - 175
       TE012_4           176 - 176
       TE012_5           177 - 177
       TE012_6           178 - 178
       TE013_011         179 - 179
       TE013_012         180 - 180
       TE013_021         181 - 181
       TE013_022         182 - 182
       TE013_031         183 - 183
       TE013_032         184 - 184
       TE013_041         185 - 185
       TE013_042         186 - 186
       TE013_051         187 - 187
       TE013_052         188 - 188
       TE013_061         189 - 189
       TE013_062         190 - 190
       TE013_071         191 - 191
       TE013_072         192 - 192
       TE013_081         193 - 193
       TE013_082         194 - 194
       TE013_091         195 - 195
       TE013_092         196 - 196
       TE013_101         197 - 197
       TE013_102         198 - 198
       TE013_111         199 - 199
       TE013_112         200 - 200
       TE014_1           201 - 201
       TE014_2           202 - 202
       TE014_3           203 - 203
       TE014_4           204 - 204
       TE014_5           205 - 205
       TE014_6           206 - 206
       TE014_7           207 - 207
       TE014_8           208 - 208
       TE015             209 - 209
       TE016             210 - 210
       TE017             211 - 211
       TE018             212 - 212
       TE019             213 - 213
       TE020             214 - 214
       TE021             215 - 215
       TE022             216 - 216
       TE023             217 - 217
       TE024             218 - 218
       TE025             219 - 219
       TE026             220 - 222
       TE027             223 - 225
       TE028_1           226 - 226
       TE028_2           227 - 227
       TE028_3           228 - 228
       TE028_4           229 - 229
       TE028_5           230 - 230
       TE028_6           231 - 231
       TE028_7           232 - 232
       TE028_8           233 - 233
       WVARSTRR          234 - 235
       W_FSTR1           236 - 246
       W_FSTR2           247 - 257
       W_FSTR3           258 - 268
       W_FSTR4           269 - 279
       W_FSTR5           280 - 290
       W_FSTR6           291 - 301
       W_FSTR7           302 - 312
       W_FSTR8           313 - 323
       W_FSTR9           324 - 334
       W_FSTR10          335 - 345
       W_FSTR11          346 - 356
       W_FSTR12          357 - 367
       W_FSTR13          368 - 378
       W_FSTR14          379 - 389
       W_FSTR15          390 - 400
       W_FSTR16          401 - 411
       W_FSTR17          412 - 422
       W_FSTR18          423 - 433
       W_FSTR19          434 - 444
       W_FSTR20          445 - 455
       W_FSTR21          456 - 466
       W_FSTR22          467 - 477
       W_FSTR23          478 - 488
       W_FSTR24          489 - 499
       W_FSTR25          500 - 510
       W_FSTR26          511 - 521
       W_FSTR27          522 - 532
       W_FSTR28          533 - 543
       W_FSTR29          544 - 554
       W_FSTR30          555 - 565
       W_FSTR31          566 - 576
       W_FSTR32          577 - 587
       W_FSTR33          588 - 598
       W_FSTR34          599 - 609
       W_FSTR35          610 - 620
       W_FSTR36          621 - 631
       W_FSTR37          632 - 642
       W_FSTR38          643 - 653
       W_FSTR39          654 - 664
       W_FSTR40          665 - 675
       W_FSTR41          676 - 686
       W_FSTR42          687 - 697
       W_FSTR43          698 - 708
       W_FSTR44          709 - 719
       W_FSTR45          720 - 730
       W_FSTR46          731 - 741
       W_FSTR47          742 - 752
       W_FSTR48          753 - 763
       W_FSTR49          764 - 774
       W_FSTR50          775 - 785
       W_FSTR51          786 - 796
       W_FSTR52          797 - 807
       W_FSTR53          808 - 818
       W_FSTR54          819 - 829
       W_FSTR55          830 - 840
       W_FSTR56          841 - 851
       W_FSTR57          852 - 862
       W_FSTR58          863 - 873
       W_FSTR59          874 - 884
       W_FSTR60          885 - 895
       W_FSTR61          896 - 906
       W_FSTR62          907 - 917
       W_FSTR63          918 - 928
       W_FSTR64          929 - 939
       W_FSTR65          940 - 950
       W_FSTR66          951 - 961
       W_FSTR67          962 - 972
       W_FSTR68          973 - 983
       W_FSTR69          984 - 994
       W_FSTR70          995 - 1005
       W_FSTR71         1006 - 1016
       W_FSTR72         1017 - 1027
       W_FSTR73         1028 - 1038
       W_FSTR74         1039 - 1049
       W_FSTR75         1050 - 1060
       W_FSTR76         1061 - 1071
       W_FSTR77         1072 - 1082
       W_FSTR78         1083 - 1093
       W_FSTR79         1094 - 1104
       W_FSTR80         1105 - 1115
;





   LABEL
     NACIONAL        ="Variable auxiliar para obtener promedios nacionales"
     ESCUELA         ="Identificador de la escuela"
     ID_ENT          ="Entidad federativa (identificador numrico)"
     NOM_ENT         ="Entidad federativa"
     ID_MOD          ="Estrato escolar o Modalidad educativa (identificador numrico)"
     MOD             ="Estrato escolar o Modalidad educativa"
     ESTRATO         ="Estratos del diseo muestral con el que se estiman los parmetros y errores estndar"
     ALUMNO          ="Identificador del alumno"
     ID_INSTR        ="Identificador del cuadernillo de examen"
     SEXO            ="Sexo del alumno"
     FECHA_NAC       ="Fecha de nacimiento del alumno DD/MM/AAAA"
     EDAD            ="Edad del alumno al mes de mayo de 2011, en aos (al momento de la aplicacin)"
     EDADC           ="Edad del alumno al mes de mayo de 2011, codificada (al momento de la aplicacin)"
     EDADN           ="Edad normativa"
     EDAD_AC         ="Edad en aos cumplidos (al momento de la aplicacin)"
     W_ALU           ="Peso muestral o ponderador del alumno"
     I_PADRES        ="Identificador de los padres que contestaron el cuestionario"
     PARENT          ="Es usted el padre o la madre del nio?"
     TE001           ="Cuntos aos cumplidos tiene usted?"
     TE002_1         ="Llevo al nio a la escuela porque... es obligatorio"
     TE002_2         ="Llevo al nio a la escuela porque... necesita aprender a leer, escribir, hacer cuentas y otros conocimientos"
     TE002_3         ="Llevo al nio a la escuela porque... con educacin tendr un mejor futuro"
     TE002_4         ="Llevo al nio a la escuela porque... estudiar le ayudar a ser una mejor persona"
     TE002_5         ="Llevo al nio a la escuela porque... Otra razn"
     TE003_1         ="En el ltimo mes, cuntos das hizo usted las siguientes cosas con el nio? Jugu con l"
     TE003_2         ="En el ltimo mes, cuntos das hizo usted las siguientes cosas con el nio? Le le o le cont historias"
     TE003_3         ="En el ltimo mes, cuntos das hizo usted las siguientes cosas con el nio? Cantamos"
     TE003_4         ="En el ltimo mes, cuntos das hizo usted las siguientes cosas con el nio? Fuimos de paseo"
     TE003_5         ="En el ltimo mes, cuntos das hizo usted las siguientes cosas con el nio? Me di cuenta de que haba aprendido algo nuevo"
     TE003_6         ="En el ltimo mes, cuntos das hizo usted las siguientes cosas con el nio? Respond a sus preguntas"
     TE003_7         ="En el ltimo mes, cuntos das hizo usted las siguientes cosas con el nio? Vimos televisin"
     TE003_8         ="En el ltimo mes, cuntos das hizo usted las siguientes cosas con el nio? Hicimos actividades manuales (dibujar, recortar)"
     TE003_9         ="En el ltimo mes, cuntos das hizo usted las siguientes cosas con el nio? Le ense letras, palabras o nmeros"
     TE004_01        ="En el ltimo mes, cuntos das pasaron las siguientes cosas? Le pregunt al nio qu hizo en la escuela"
     TE004_02        ="En el ltimo mes, cuntos das pasaron las siguientes cosas? Habl con otras mams sobre el aprendizaje de los nios"
     TE004_03        ="En el ltimo mes, cuntos das pasaron las siguientes cosas? Pregunt por el avance del nio"
     TE004_04        ="En el ltimo mes, cuntos das pasaron las siguientes cosas? Pregunt por su comportamiento"
     TE004_05        ="En el ltimo mes, cuntos das pasaron las siguientes cosas? Ped consejo a la maestra"
     TE004_06        ="En el ltimo mes, cuntos das pasaron las siguientes cosas? Ped explicaciones a la maestra"
     TE004_07        ="En el ltimo mes, cuntos das pasaron las siguientes cosas? Ped informacin sobre material o actividades a la maestra"
     TE004_08        ="En el ltimo mes, cuntos das pasaron las siguientes cosas? Realic con el nio las actividades que le dejan en la escuela"
     TE004_09        ="En el ltimo mes, cuntos das pasaron las siguientes cosas? La maestra habl conmigo para pedirme material o cuotas"
     TE004_10        ="En el ltimo mes, cuntos das pasaron las siguientes cosas? La maestra me pidi apoyo para alguna actividad escolar"
     TE004_11        ="En el ltimo mes, cuntos das pasaron las siguientes cosas? La maestra me busc para hablar sobre el nio"
     TE004_12        ="En el ltimo mes, cuntos das pasaron las siguientes cosas? La maestra me pidi que le hiciera cosas en casa para apoyar el aprendizaje del nio"
     TE004_13        ="En el ltimo mes, cuntos das pasaron las siguientes cosas? La maestra dej actividades que necesitan de la ayuda de algn adulto"
     TE005_1         ="Qu debera aprender su hijo en el preescolar? Leer y escribir, hacer cuentas, los colores y otros conocimientos"
     TE005_2         ="Qu debera aprender su hijo en el preescolar? Valores, hbitos, reglas de convivencia, participacin social"
     TE005_3         ="Qu debera aprender su hijo en el preescolar? Computacin e idiomas"
     TE005_4         ="Qu debera aprender su hijo en el preescolar? A expresarse correctamente"
     TE005_5         ="Qu debera aprender su hijo en el preescolar? Cuidado del ambiente"
     TE005_6         ="Qu debera aprender su hijo en el preescolar? Cultura general"
     TE006_1         ="Qu cosas tendra que hacer la escuela para asegurar que sus alumnos aprendan? Tener maestros suficientes, bien capacitados y comprometidos"
     TE006_2         ="Qu cosas tendra que hacer la escuela para asegurar que sus alumnos aprendan? Motivar a los nios"
     TE006_3         ="Qu cosas tendra que hacer la escuela para asegurar que sus alumnos aprendan? Tener buenas instalaciones y materiales para las clases"
     TE006_4         ="Qu cosas tendra que hacer la escuela para asegurar que sus alumnos aprendan? Cumplir con el horario diario y no suspender clases"
     TE006_5         ="Qu cosas tendra que hacer la escuela para asegurar que sus alumnos aprendan? Conseguir apoyos externos"
     TE006_6         ="Qu cosas tendra que hacer la escuela para asegurar que sus alumnos aprendan? Promover la comunicacin entre padres y maestros"
     TE006_7         ="Qu cosas tendra que hacer la escuela para asegurar que sus alumnos aprendan? Respetar el programa"
     TE007           ="En su opinin, existe alguna relacin entre lo que aprenden los nios en la escuela y los que se les ensea en casa?"
     TE008           ="Cuando el nio no quiere ir a la escuela, cmo lo convence?"
     TE009           ="Qu opina usted sobre el horario de preescolar?"
     TE010           ="Qu opina de las actividades escolares en las que los padres pueden participar?"
     TE011_01        ="Marque si ha participado o no en las siguientes actividades escolares durante este ao. Juntas"
     TE011_02        ="Marque si ha participado o no en las siguientes actividades escolares durante este ao. Festivales"
     TE011_03        ="Marque si ha participado o no en las siguientes actividades escolares durante este ao. Actividades de la asociacin de padres"
     TE011_04        ="Marque si ha participado o no en las siguientes actividades escolares durante este ao. Mantenimiento y limpieza de la escuela"
     TE011_05        ="Marque si ha participado o no en las siguientes actividades escolares durante este ao. Actividades junto con los nios durante las clases (contar cuentos, dibujar)"
     TE011_06        ="Marque si ha participado o no en las siguientes actividades escolares durante este ao. Cursos o plticas para padres"
     TE011_07        ="Marque si ha participado o no en las siguientes actividades escolares durante este ao. Actividades culturales (teatro, tteres, conciertos)"
     TE011_08        ="Marque si ha participado o no en las siguientes actividades escolares durante este ao. Actividades de educacin ambiental"
     TE011_09        ="Marque si ha participado o no en las siguientes actividades escolares durante este ao. Actividades deportivas"
     TE011_10        ="Marque si ha participado o no en las siguientes actividades escolares durante este ao. Paseos fuera de la escuela"
     TE011_11        ="Marque si ha participado o no en las siguientes actividades escolares durante este ao. Clases pblicas o abiertas"
     TE012_1         ="Marque en cada rengln si le gustara o no que la maestra del nio lo invitara a participar en las siguientes actividades. Actividades junto con los nios durante las clases (contar cuentos, dibujar)"
     TE012_2         ="Marque en cada rengln si le gustara o no que la maestra del nio lo invitara a participar en las siguientes actividades. Actividades deportivas"
     TE012_3         ="Marque en cada rengln si le gustara o no que la maestra del nio lo invitara a participar en las siguientes actividades. Actividades culturales (teatro, tteres, conciertos)"
     TE012_4         ="Marque en cada rengln si le gustara o no que la maestra del nio lo invitara a participar en las siguientes actividades. Paseos fuera de la escuela"
     TE012_5         ="Marque en cada rengln si le gustara o no que la maestra del nio lo invitara a participar en las siguientes actividades. Campaas de la educacin ambiental"
     TE012_6         ="Marque en cada rengln si le gustara o no que la maestra del nio lo invitara a participar en las siguientes actividades. Cursos o plticas para los padres"
     TE013_011       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Dar a los nios herramientas para el futuro 'La escuela es la responsable'"
     TE013_012       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Dar a los nios herramientas para el futuro 'La familia es la responsable'"
     TE013_021       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearles buenos hbitos 'La escuela es la responsable'"
     TE013_022       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearles buenos hbitos  'La familia es la responsable'"
     TE013_031       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearles valores morales 'La escuela es la responsable'"
     TE013_032       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearles valores morales 'La familia es la responsable'"
     TE013_041       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearles a leer, escribir, hacer cuentas 'La escuela es la responsable'"
     TE013_042       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearles a leer, escribir, hacer cuentas 'La familia es la responsable'"
     TE013_051       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ayudarlos a ser mejores personas 'La escuela es la responsable'"
     TE013_052       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ayudarlos a ser mejores personas 'La familia es la responsable'"
     TE013_061       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearlos a ser buenos ciudadanos 'La escuela es la responsable'"
     TE013_062       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearlos a ser buenos ciudadanos 'La familia es la responsable'"
     TE013_071       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearlos a que aprendan por s mismos 'La escuela es la responsable'"
     TE013_072       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearlos a que aprendan por s mismos 'La familia es la responsable'"
     TE013_081       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Motivarlos a aprender 'La escuela es la responsable'"
     TE013_082       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Motivarlos a aprender 'La familia es la responsable'"
     TE013_091       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearlos a relacionarse bien con los dems 'La escuela es la responsable'"
     TE013_092       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearlos a relacionarse bien con los dems 'La familia es la responsable'"
     TE013_101       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearlos a expresarse correctamente 'La escuela es la responsable'"
     TE013_102       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearlos a expresarse correctamente 'La familia es la responsable'"
     TE013_111       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearlos a aplicar lo que aprenden 'La escuela es la responsable'"
     TE013_112       ="Marque si las siguientes acciones son responsabilidad de la escuela o de la familia. Ensearlos a aplicar lo que aprenden 'La familia es la responsable'"
     TE014_1         ="En una semana normal, cuntos das el nio hace las siguientes actividades? Juega solo"
     TE014_2         ="En una semana normal, cuntos das el nio hace las siguientes actividades? Juega con otros nios"
     TE014_3         ="En una semana normal, cuntos das el nio hace las siguientes actividades? Ayuda a las labores de la casa"
     TE014_4         ="En una semana normal, cuntos das el nio hace las siguientes actividades? Pasa ms de una hora sin hacer nada"
     TE014_5         ="En una semana normal, cuntos das el nio hace las siguientes actividades? Ve libros solo"
     TE014_6         ="En una semana normal, cuntos das el nio hace las siguientes actividades? Usa la computadora solo"
     TE014_7         ="En una semana normal, cuntos das el nio hace las siguientes actividades? Ve ms de una hora la televisin"
     TE014_8         ="En una semana normal, cuntos das el nio hace las siguientes actividades? Trabaja para ayudar a la familia"
     TE015           ="La mayora de las veces, quin lleva y recoge al nio del preescolar?"
     TE016           ="Llevar y recoger al nio le dificulta cumplir con sus otras actividades diarias?"
     TE017           ="Qu opina usted sobre que el preescolar sea obligatorio?"
     TE018           ="Qu lengua aprendi el nio a hablar primero?"
     TE019           ="Qu lengua se habla en la casa del nio la mayor parte de tiempo?"
     TE020           ="De qu material es el piso de la casa conde vive el nio?"
     TE021           ="Cuntos cuartos de bao hay en la casa donde vive el nio?"
     TE022           ="Hasta qu nivel educativo termin la madre o tutora del nio?"
     TE023           ="Hasta qu nivel educativo termin el padre o tutor del nio?"
     TE024           ="Cuntos aos, adems de este, el nio ha ido a la escuela?"
     TE025           ="Hasta qu nivel educativo les gustara que estudiara el nio?"
     TE026           ="Sin contar revistas, peridicos o libros escolares, aproximadamente cuntos libros hay en la casa del nio?"
     TE027           ="Aproximadamente, cuntos focos hay en la casa donde vive el nio?"
     TE028_1         ="Marque todos los bienes y servicios que hay en la casa donde vive el nio Drenaje"
     TE028_2         ="Marque todos los bienes y servicios que hay en la casa donde vive el nio Telfono"
     TE028_3         ="Marque todos los bienes y servicios que hay en la casa donde vive el nio Televisin por cable o satlite"
     TE028_4         ="Marque todos los bienes y servicios que hay en la casa donde vive el nio Internet"
     TE028_5         ="Marque todos los bienes y servicios que hay en la casa donde vive el nio Computadora"
     TE028_6         ="Marque todos los bienes y servicios que hay en la casa donde vive el nio Auto, coche o camioneta"
     TE028_7         ="Marque todos los bienes y servicios que hay en la casa donde vive el nio Lavadora"
     TE028_8         ="Marque todos los bienes y servicios que hay en la casa donde vive el nio Horno de microondas"
     WVARSTRR        ="Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
     W_FSTR1         ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR2         ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR3         ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR4         ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR5         ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR6         ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR7         ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR8         ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR9         ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR10        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR11        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR12        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR13        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR14        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR15        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR16        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR17        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR18        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR19        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR20        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR21        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR22        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR23        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR24        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR25        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR26        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR27        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR28        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR29        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR30        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR31        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR32        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR33        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR34        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR35        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR36        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR37        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR38        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR39        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR40        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR41        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR42        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR43        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR44        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR45        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR46        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR47        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR48        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR49        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR50        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR51        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR52        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR53        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR54        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR55        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR56        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR57        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR58        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR59        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR60        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR61        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR62        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR63        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR64        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR65        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR66        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR67        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR68        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR69        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR70        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR71        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR72        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR73        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR74        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR75        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR76        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR77        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR78        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR79        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR80        ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"

;





   FORMAT
       NACIONAL           1.
       ESCUELA            4.
       ID_ENT             id_entF.
       NOM_ENT            $char19.
       ID_MOD             id_modF.
       MOD                $modF.
       ESTRATO            $char6.
       ALUMNO             5.
       ID_INSTR           $char15.
       SEXO               sexoF.
       FECHA_NAC          $char10.
       EDAD               edadF.
       EDADC              edadcF.
       EDADN              edadnF.
       EDAD_AC            edad_acF.
       I_PADRES           i_padreF.
       PARENT             parentF.
       TE001              T1F.
       TE002_1            T2F.
       TE002_2            T2F.
       TE002_3            T2F.
       TE002_4            T2F.
       TE002_5            T2F.
       TE003_1            T3F.
       TE003_2            T3F.
       TE003_3            T3F.
       TE003_4            T3F.
       TE003_5            T3F.
       TE003_6            T3F.
       TE003_7            T3F.
       TE003_8            T3F.
       TE003_9            T3F.
       TE004_01           T4F.
       TE004_02           T4F.
       TE004_03           T4F.
       TE004_04           T4F.
       TE004_05           T4F.
       TE004_06           T4F.
       TE004_07           T4F.
       TE004_08           T4F.
       TE004_09           T4F.
       TE004_10           T4F.
       TE004_11           T4F.
       TE004_12           T4F.
       TE004_13           T4F.
       TE005_1            T5F.
       TE005_2            T5F.
       TE005_3            T5F.
       TE005_4            T5F.
       TE005_5            T5F.
       TE005_6            T5F.
       TE006_1            T6F.
       TE006_2            T6F.
       TE006_3            T6F.
       TE006_4            T6F.
       TE006_5            T6F.
       TE006_6            T6F.
       TE006_7            T6F.
       TE007              T7F.
       TE008              T8F.
       TE009              T9F.
       TE010              T10F.
       TE011_01           T11F.
       TE011_02           T11F.
       TE011_03           T11F.
       TE011_04           T11F.
       TE011_05           T11F.
       TE011_06           T11F.
       TE011_07           T11F.
       TE011_08           T11F.
       TE011_09           T11F.
       TE011_10           T11F.
       TE011_11           T11F.
       TE012_1            T12F.
       TE012_2            T12F.
       TE012_3            T12F.
       TE012_4            T12F.
       TE012_5            T12F.
       TE012_6            T12F.
       TE013_011          T13F.
       TE013_012          T13F.
       TE013_021          T13F.
       TE013_022          T13F.
       TE013_031          T13F.
       TE013_032          T13F.
       TE013_041          T13F.
       TE013_042          T13F.
       TE013_051          T13F.
       TE013_052          T13F.
       TE013_061          T13F.
       TE013_062          T13F.
       TE013_071          T13F.
       TE013_072          T13F.
       TE013_081          T13F.
       TE013_082          T13F.
       TE013_091          T13F.
       TE013_092          T13F.
       TE013_101          T13F.
       TE013_102          T13F.
       TE013_111          T13F.
       TE013_112          T13F.
       TE014_1            T14F.
       TE014_2            T14F.
       TE014_3            T14F.
       TE014_4            T14F.
       TE014_5            T14F.
       TE014_6            T14F.
       TE014_7            T14F.
       TE014_8            T14F.
       TE015              T15F.
       TE016              T16F.
       TE017              T17F.
       TE018              T18_19F.
       TE019              T18_19F.
       TE020              T20F.
       TE021              T21F.
       TE022              T22_23F.
       TE023              T22_23F.
       TE024              T24F.
       TE025              T25F.
       TE026              T26F.
       TE027              T27F.
       TE028_1            T28F.
       TE028_2            T28F.
       TE028_3            T28F.
       TE028_4            T28F.
       TE028_5            T28F.
       TE028_6            T28F.
       TE028_7            T28F.
       TE028_8            T28F.
       wvarstrr           2.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;

   ARRAY perdidos1(3)  sexo edadc edadn;
   DO  i=1 TO 3;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(2)  edad edad_ac;
   DO  i=1 TO 2;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;


   ARRAY perdidos3(89)
                   PARENT te002_1 te002_2 te002_3 te002_4 te002_5 te005_1 te005_2 te005_3 te005_4 te005_5
                   te005_6 te006_1 te006_2 te006_3 te006_4 te006_5 te006_6 te006_7 te007 te008 te009
                   te010 te011_01 te011_02 te011_03 te011_04 te011_05 te011_06 te011_07 te011_08 te011_09
                   te011_10 te011_11 te012_1 te012_2 te012_3 te012_4 te012_5 te012_6 te013_011 te013_012
                   te013_021 te013_022 te013_031 te013_032 te013_041 te013_042 te013_051 te013_052 te013_061
                   te013_062 te013_071 te013_072 te013_081 te013_082 te013_091 te013_092 te013_101 te013_102
                   te013_111 te013_112 te014_1 te014_2 te014_3 te014_4 te014_5 te014_6 te014_7 te014_8 te015
                   te016 te017 te018 te019 te020 te021 te022 te023 te024 te025 te028_1 te028_2 te028_3 te028_4
                   te028_5 te028_6 te028_7 te028_8;
   DO  i=1 TO 89;
          IF perdidos3{i} = 6   THEN  perdidos3{i} = .I;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;


   ARRAY perdidos4(23)
                   te001 te003_1 te003_2 te003_3 te003_4 te003_5 te003_6 te003_7 te003_8 te003_9
                   te004_01 te004_02 te004_03 te004_04 te004_05 te004_06 te004_07 te004_08 te004_09
                   te004_10 te004_11 te004_12 te004_13;
   DO  i=1 TO 23;
          IF perdidos4{i} = 97   THEN  perdidos4{i} = .N;
          IF perdidos4{i} = 98   THEN  perdidos4{i} = .M;
          IF perdidos4{i} = 99   THEN  perdidos4{i} = .S;
   END;

   ARRAY perdidos5(2)
                    te026 te027;
   DO  i=1 TO 2;
          IF perdidos5{i} = 998   THEN  perdidos5{i} = .M;
          IF perdidos5{i} = 999   THEN  perdidos5{i} = .S;
   END;


   drop i;
RUN;
